command_connection_program

Function command_connection_program 

pub async fn command_connection_program(
    input: InputStream<CommandProgramSocketMessage>,
    context: SceneContext,
    command_target: impl Into<StreamTarget>,
)
The command program accepts connections from a socket and will generate command output messages

Commands will be sent to the command target (as JsonCommand requests). JsonCommand will create a default dispatcher, which will send commands to whichever subprogram can respond: use StreamTarget::Any to target this dispatcher.

(JsonCommands are a bit inefficient due to the need for a filter, but sending them will ensure that the dispatcher is started)