JsonParseError

Enum JsonParseError 

pub enum JsonParseError {
    UnexpectedToken(Option<JsonToken>, String),
    ExpectedColon(Option<JsonToken>, String),
    ExpectedMoreInput(JsonInputType),
    ParserStackTooSmall,
    SerdeJsonError,
    ParserDidNotConverge,
    CommandExpectedMoreInput,
}
Errors that can occur while parsing JSON

Variants



UnexpectedToken(Option<JsonToken>, String)

The lookahead wasn’t expected at this point



ExpectedColon(Option<JsonToken>, String)

Expected a ‘:’ character, but got something else



ExpectedMoreInput(JsonInputType)

The parser succeded in matching the input, but more was expected



ParserStackTooSmall

Usually an error in the parser, we tried to ‘reduce’ a token when we hadn’t previously accepted enough input



SerdeJsonError

A value that the parser thought was valid JSON was rejected by serde (usually indicating an error in this parser)



ParserDidNotConverge

Usually indicates an error with the parser, we failed to ‘converge’ to a single value



CommandExpectedMoreInput

Expected more input while parsing a substituted command

Implementations

Source

impl JsonParseError

pub fn describe(&self) -> String

Produces a human readable description of this error