json_parse_string

Function json_parse_string 

pub async fn json_parse_string<TStream, TToken>(
    parser: &mut Parser<TokenMatch<TToken>, ParsedJson>,
    tokenizer: &mut Tokenizer<TToken, TStream>,
) -> Result<(), JsonParseError>
where TStream: Send + Stream<Item = Vec<u8>>, TToken: Clone + Send + TryInto<JsonToken>, TToken::Error: Send,
Attempts to parse a JSON string starting at the current location in the tokenizer, leaving the result on top of the stack in the parser (or returning an error state if the value is not recognised)