pub async fn command_stream(
source: Vec<Value>,
_context: SceneContext,
) -> CommandResponseExpand description
The stream command, which turns its argument into a JSON stream result
pub async fn command_stream(
source: Vec<Value>,
_context: SceneContext,
) -> CommandResponseThe stream command, which turns its argument into a JSON stream result