SocketConnection

Struct SocketConnection 

pub struct SocketConnection<TInputMessage, TOutputMessage> { /* private fields */ }
Represents an incoming socket connection. When a socket is connected, we retrieve an input stream, and need to respond with an output stream.

The socket is closed when the output stream is closed, or when the connection itself is dropped.

Implementations

Source

impl<TInputMessage, TOutputMessage> SocketConnection<TInputMessage, TOutputMessage>
where TInputMessage: 'static, TOutputMessage: 'static,

pub fn new( context: &SceneContext, input: impl 'static + Send + Stream<Item = TInputMessage>, send_output: impl 'static + Send + FnOnce(&SceneContext, BoxStream<'static, TOutputMessage>), ) -> Self

Creates a new socket connection

pub fn connect( self, output_stream: impl 'static + Send + Stream<Item = TOutputMessage>, ) -> BoxStream<'static, TInputMessage>

Sets the stream that will send the resulting output to the socket, and returns the input stream that can be used to read incoming data