Attempts to parse a JSON array starting at the current location in the tokenizer, leaving the result on top of the stack in the parser
(or returning an error state if the value is not recognised)
Attempts to parse a JSON object starting at the current location in the tokenizer, leaving the result on top of the stack in the parser
(or returning an error state if the value is not recognised)
Attempts to parse a JSON object starting at the current location in the tokenizer, leaving the result on top of the stack in the parser
(or returning an error state if the value is not recognised)
Attempts to parse a JSON string starting at the current location in the tokenizer, leaving the result on top of the stack in the parser
(or returning an error state if the value is not recognised)
Attempts to parse a JSON value starting at the current location in the tokenizer, leaving the result on top of the stack in the parser
(or returning an error state if the value is not recognised)
Attempts to parse a JSON value starting at the current location in the tokenizer, leaving the result on top of the stack in the parser
(or returning an error state if the value is not recognised)