pub async fn json_parse_string<TStream, TToken>(
parser: &mut Parser<TokenMatch<TToken>, ParsedJson>,
tokenizer: &mut Tokenizer<TToken, TStream>,
) -> Result<(), JsonParseError>Expand description
Attempts to parse a JSON string starting at the current location in the tokenizer, leaving the result on top of the stack in the parser (or returning an error state if the value is not recognised)