pub struct SocketConnection<TInputMessage, TOutputMessage> { /* private fields */ }Expand description
Represents an incoming socket connection. When a socket is connected, we retrieve an input stream, and need to respond with an output stream.
The socket is closed when the output stream is closed, or when the connection itself is dropped.
Implementations
Sourceimpl<TInputMessage, TOutputMessage> SocketConnection<TInputMessage, TOutputMessage>where
TInputMessage: 'static,
TOutputMessage: 'static,
impl<TInputMessage, TOutputMessage> SocketConnection<TInputMessage, TOutputMessage>where
TInputMessage: 'static,
TOutputMessage: 'static,
Sourcepub fn new(
context: &SceneContext,
input: impl 'static + Send + Stream<Item = TInputMessage>,
send_output: impl 'static + Send + FnOnce(&SceneContext, BoxStream<'static, TOutputMessage>),
) -> Self
pub fn new( context: &SceneContext, input: impl 'static + Send + Stream<Item = TInputMessage>, send_output: impl 'static + Send + FnOnce(&SceneContext, BoxStream<'static, TOutputMessage>), ) -> Self
Creates a new socket connection